@@ -289,7 +289,7 @@ def compile_rules(*rules, **kwargs):
 
 def load_rules(*rules, **kwargs):
 
-    rules = [sanirule(r) for r in rules]
+    rules = [sanirule(r, drop_history=True) for r in rules]
 
     soname = compile_rules(*rules, **kwargs)
     from .pythlib import Session
