@@ -33,7 +33,7 @@ def create_rule(rulestring):
 
     rule_property(rulestring, 'create_rule')
 
-def sanirule(rulestring):
+def sanirule(rulestring, drop_history=False):
 
     if '.' in rulestring:
         rulestring = rule2files(rulestring)
@@ -43,7 +43,7 @@ def sanirule(rulestring):
     rulestring = rulestring.lower()
 
     if (len(rulestring) > 7) and (rulestring[-7:] == 'history'):
-        return sanirule(rulestring[:-7]) + 'History'
+        return sanirule(rulestring[:-7], drop_history) + ('' if drop_history else 'History')
 
     if '/' in rulestring:
         rparts = rulestring.split('/')
