@@ -435,6 +435,26 @@ class Pattern(object):
     # include it as an alias for Pattern.write_file():
     save = write_file
 
+
+    def rle_string(self, filename=None, autoremove=True):
+
+        if filename is None:
+            filename = self.session.newfloat('pattern') + '.rle'
+
+        self.write_rle(filename)
+
+        with open(filename, 'rb') as f:
+            rs = regstring(f.read())
+
+        if autoremove:
+            try:
+                os.remove(filename)
+            except OSError:
+                pass
+
+        return rs
+
+
     def viewer(self, filename=None, width=480, height=480, base64=True,
                 lv_config='#C [[ THEME 6 GRID GRIDMAJOR 0 ]]', autoremove=True):
 
